==> kaddressbook-22.11.80.tar.xz: kaddressbook-22.11.80/kontactplugin/kaddressbookplugin.json.cmake <==
{
    "KPlugin": {
        "Description": "Kontact KAddressBook Plugin",
        "Description[ar]": "ملحقة «دفتر عناوينك» ل‍«متراسلك»",
        "Description[az]": "Kontact KAddressBook qoşması",
        "Description[bg]": "Приставка за контакти на KAddressBook",
        "Description[ca@valencia]": "Connector de la llibreta d'adreces de Kontact",
        "Description[ca]": "Connector de la llibreta d'adreces del Kontact",
        "Description[cs]": "Modul Knihy adres pro Kontact",
        "Description[de]": "Adressbuch-Modul für Kontact",
        "Description[en_GB]": "Kontact KAddressBook Plugin",
        "Description[es]": "Complemento KAddressBook de Kontact",
        "Description[eu]": "Kontact KAddressBook plugina",
        "Description[fi]": "Kontactin KAddressBook-liitännäinen",
        "Description[fr]": "Module externe « KAddressBook » de Kontact",
        "Description[ia]": "Plug-in pro Kontact KAddressBook",
        "Description[it]": "Estensione per Kontact di KAddressbook",
        "Description[ka]": "Kontact -ის დამატება KAddressBook-ისთვის",
        "Description[ko]": "Kontact KAddressBook 플러그인",
        "Description[nl]": "Kontact KAddressBook-plug-in",
        "Description[pl]": "Wtyczka Kontact do współpracy z Książką Adresową",
        "Description[pt]": "'Plugin' de KAddressBook do Kontact",
        "Description[pt_BR]": "Plugin do KAddressBook para o Kontact",
        "Description[sk]": "Kontact KAddressBook Plugin",
        "Description[sl]": "Vtičnik Kontact adresar",
        "Description[sv]": "Kontact-insticksprogram för adressbok",
        "Description[tr]": "Kontact K Adres Defteri Eklentisi",
        "Description[uk]": "Додаток адресної книги Kontact",
        "Description[x-test]": "xxKontact KAddressBook Pluginxx",
        "EnabledByDefault": true,
        "Icon": "view-pim-contacts",
        "Id": "kontact_kaddressbookplugin",
        "License": "GPL",
        "Name": "Contacts",
        "Name[ar]": "المتراسلون",
        "Name[az]": "Əlaqələr",
        "Name[bg]": "Контакти",
        "Name[ca@valencia]": "Contactes",
        "Name[ca]": "Contactes",
        "Name[cs]": "Kontakty",
        "Name[de]": "Kontakte",
        "Name[en_GB]": "Contacts",
        "Name[es]": "Contactos",
        "Name[eu]": "Kontaktuak",
        "Name[fi]": "Yhteystiedot",
        "Name[fr]": "Contacts",
        "Name[ia]": "Contactos",
        "Name[it]": "Contatti",
        "Name[ka]": "კონტაქტები",
        "Name[ko]": "연락처",
        "Name[nl]": "Contactpersonen",
        "Name[pl]": "Kontakty",
        "Name[pt]": "Contactos",
        "Name[pt_BR]": "Contatos",
        "Name[ru]": "Контакты",
        "Name[sk]": "Kontakty",
        "Name[sl]": "Contacts",
        "Name[sv]": "Kontakter",
        "Name[tr]": "Kişiler",
        "Name[uk]": "Контакти",
        "Name[x-test]": "xxContactsxx",
        "Version": "0.1"
    },
    "X-KDE-ConfigModuleNamespace": "pim@QT_MAJOR_VERSION@/kcms/kaddressbook/",
    "X-KDE-KontactPartExecutableName": "kaddressbook",
    "X-KDE-KontactPartLibraryName": "kaddressbookpart",
    "X-KDE-KontactPartLoadOnStart": false,
    "X-KDE-KontactPluginHasSummary": false,
    "X-KDE-KontactPluginVersion": 11,
    "X-KDE-Weight": "300"
}

==> kaddressbook-23.03.90.tar.xz: kaddressbook-23.03.90/kontactplugin/kaddressbookplugin.json.cmake <==
{
    "KPlugin": {
        "Description": "Kontact KAddressBook Plugin",
        "Description[ar]": "ملحقة «دفتر عناوينك» ل‍«متراسلك»",
        "Description[az]": "Kontact KAddressBook qoşması",
        "Description[bg]": "Приставка за контакти на KAddressBook",
        "Description[ca@valencia]": "Connector de la llibreta d'adreces de Kontact",
        "Description[ca]": "Connector de la llibreta d'adreces del Kontact",
        "Description[cs]": "Modul Knihy adres pro Kontact",
        "Description[de]": "Adressbuch-Modul für Kontact",
        "Description[el]": "Πρόσθετο KAddressBook του Kontact",
        "Description[en_GB]": "Kontact KAddressBook Plugin",
        "Description[eo]": "KAddressBook-Kromprogramo de Kontact",
        "Description[es]": "Complemento KAddressBook de Kontact",
        "Description[eu]": "Kontact KAddressBook plugina",
        "Description[fi]": "Kontactin KAddressBook-liitännäinen",
        "Description[fr]": "Module externe « KAddressBook » de Kontact",
        "Description[ia]": "Plug-in pro Kontact KAddressBook",
        "Description[it]": "Estensione per Kontact di KAddressbook",
        "Description[ka]": "Kontact -ის დამატება KAddressBook-ისთვის",
        "Description[ko]": "Kontact KAddressBook 플러그인",
        "Description[nl]": "Kontact KAddressBook-plug-in",
        "Description[pl]": "Wtyczka Kontact do współpracy z Książką Adresową",
        "Description[pt]": "'Plugin' de KAddressBook do Kontact",
        "Description[pt_BR]": "Plugin do KAddressBook para o Kontact",
        "Description[ru]": "Модуль KAddressBook для Kontact",
        "Description[sk]": "Kontact KAddressBook Plugin",
        "Description[sl]": "Vtičnik Kontact adresar",
        "Description[sv]": "Kontact-insticksprogram för adressbok",
        "Description[tr]": "Kontak K Adres Defteri Eklentisi",
        "Description[uk]": "Додаток адресної книги Kontact",
        "Description[x-test]": "xxKontact KAddressBook Pluginxx",
        "Description[zh_TW]": "Kontact KDE 通訊錄外掛程式",
        "EnabledByDefault": true,
        "Icon": "view-pim-contacts",
        "Id": "kontact_kaddressbookplugin",
        "License": "GPL",
        "Name": "Contacts",
        "Name[ar]": "المتراسلون",
        "Name[az]": "Əlaqələr",
        "Name[bg]": "Контакти",
        "Name[ca@valencia]": "Contactes",
        "Name[ca]": "Contactes",
        "Name[cs]": "Kontakty",
        "Name[de]": "Kontakte",
        "Name[el]": "Επαφές",
        "Name[en_GB]": "Contacts",
        "Name[eo]": "Kontaktoj",
        "Name[es]": "Contactos",
        "Name[eu]": "Kontaktuak",
        "Name[fi]": "Yhteystiedot",
        "Name[fr]": "Contacts",
        "Name[ia]": "Contactos",
        "Name[it]": "Contatti",
        "Name[ka]": "კონტაქტები",
        "Name[ko]": "연락처",
        "Name[nl]": "Contactpersonen",
        "Name[pl]": "Kontakty",
        "Name[pt]": "Contactos",
        "Name[pt_BR]": "Contatos",
        "Name[ru]": "Контакты",
        "Name[sk]": "Kontakty",
        "Name[sl]": "Contacts",
        "Name[sv]": "Kontakter",
        "Name[tr]": "Kişiler",
        "Name[uk]": "Контакти",
        "Name[x-test]": "xxContactsxx",
        "Name[zh_TW]": "聯絡人",
        "Version": "0.1"
    },
    "X-KDE-ConfigModuleNamespace": "pim@QT_MAJOR_VERSION@/kcms/kaddressbook/",
    "X-KDE-KontactPartExecutableName": "kaddressbook",
    "X-KDE-KontactPartLibraryName": "kaddressbookpart",
    "X-KDE-KontactPartLoadOnStart": false,
    "X-KDE-KontactPluginHasSummary": false,
    "X-KDE-KontactPluginVersion": 11,
    "X-KDE-Weight": "300"
}
